# <span class="badge package-core"></span> accesspolicy

## Objects

 * <span class="badge object-type-class"></span> [AccessPolicy](./object-AccessPolicy.md)
 * <span class="badge object-type-class"></span> [AccessRule](./object-AccessRule.md)
 * <span class="badge object-type-class"></span> [ResourceRef](./object-ResourceRef.md)
 * <span class="badge object-type-class"></span> [RoleRef](./object-RoleRef.md)
## Builders

 * <span class="badge builder"></span> [AccessPolicy](./builder-AccessPolicy.md)
 * <span class="badge builder"></span> [AccessRule](./builder-AccessRule.md)
 * <span class="badge builder"></span> [ResourceRef](./builder-ResourceRef.md)
 * <span class="badge builder"></span> [RoleRef](./builder-RoleRef.md)
